#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from onf_website import _
from pyams_content.component.association.interfaces import IAssociationParagraph
from pyams_content.component.links.interfaces import IInternalLink
from pyams_content.component.paragraph import IParagraphContainer
from pyams_content.component.paragraph.interfaces.html import HTML_PARAGRAPH_TYPE
from pyams_content.features.renderer.interfaces import IContentRenderer
from pyams_content.shared.common import IWfSharedContent
from pyams_default_theme.component.association import AssociationParagraphDefaultRenderer
from pyams_i18n.interfaces import II18n
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.html import html_to_text


#
# Associations paragraph default renderer
#

@adapter_config(name='default', context=(IAssociationParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/association-default.pt', layer=IPyAMSLayer)
class ONFAssociationParagraphDefaultRenderer(AssociationParagraphDefaultRenderer):
    """Associations paragraph default renderer"""

    label = _("ONF: Default associations renderer")
    weight = 1

    settings_interface = None


class ONFBaseInternalAssociationParagraphRenderer(ONFAssociationParagraphDefaultRenderer):
    """Base Internal associations paragraph renderer"""

    @staticmethod
    def is_internal_link(link):
        return IInternalLink.providedBy(link)


@adapter_config(name='resources', context=(IAssociationParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/association-resources.pt', layer=IPyAMSLayer)
class ONFInternalResourcesAssociationParagraphRenderer(ONFBaseInternalAssociationParagraphRenderer):
    """Internal resources associations paragraph renderer"""

    label = _("ONF: Internal resources sheets")
    weight = 2

    def get_associated_text(self, link):
        description = II18n(link).query_attribute('description', request=self.request)
        if description:
            return description
        if IWfSharedContent.providedBy(link.target):
            header = II18n(link.target).query_attribute('header', request=self.request)
            if header:
                return header
        container = IParagraphContainer(link.target, None)
        if container is not None:
            for paragraph in container.get_visible_paragraphs(factories=(HTML_PARAGRAPH_TYPE,)):
                return html_to_text(II18n(paragraph).query_attribute('body', request=self.request))


@adapter_config(name='reference', context=(IAssociationParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/association-reference.pt', layer=IPyAMSLayer)
class ONFInternalReferenceAssociationParagraphRenderer(ONFBaseInternalAssociationParagraphRenderer):
    """Internal references associations paragraph renderer"""

    label = _("ONF: Internal reference card renderer")
    weight = 3


@adapter_config(name='navtopic', context=(IAssociationParagraph, IPyAMSLayer), provides=IContentRenderer)
@template_config(template='templates/association-topic.pt', layer=IPyAMSLayer)
class ONFInternalTopicAssociationParagraphRenderer(ONFBaseInternalAssociationParagraphRenderer):
    """Internal topics associations paragraph renderer"""

    label = _("ONF: Internal navigation topic bloc renderer")
    weight = 4

    button_label = _("See |folder")
